# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.wrapped_response_embeddings_response import WrappedResponseEmbeddingsResponse  # noqa: E501

class TestWrappedResponseEmbeddingsResponse(unittest.TestCase):
    """WrappedResponseEmbeddingsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseEmbeddingsResponse:
        """Test WrappedResponseEmbeddingsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseEmbeddingsResponse`
        """
        model = WrappedResponseEmbeddingsResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseEmbeddingsResponse(
                done = True,
                result = openai_connector.models.embeddings_response.EmbeddingsResponse(
                    model = '', 
                    vectors = [
                        [
                            1.337
                            ]
                        ], 
                    input_tokens = 56, )
            )
        else:
            return WrappedResponseEmbeddingsResponse(
                result = openai_connector.models.embeddings_response.EmbeddingsResponse(
                    model = '', 
                    vectors = [
                        [
                            1.337
                            ]
                        ], 
                    input_tokens = 56, ),
        )
        """

    def testWrappedResponseEmbeddingsResponse(self):
        """Test WrappedResponseEmbeddingsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
