# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.chat_history_item import ChatHistoryItem  # noqa: E501

class TestChatHistoryItem(unittest.TestCase):
    """ChatHistoryItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatHistoryItem:
        """Test ChatHistoryItem
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatHistoryItem`
        """
        model = ChatHistoryItem()  # noqa: E501
        if include_optional:
            return ChatHistoryItem(
                role = 'user',
                content = [
                    openai_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                        type = 'text', 
                        text = '', )
                    ]
            )
        else:
            return ChatHistoryItem(
                role = 'user',
                content = [
                    openai_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                        type = 'text', 
                        text = '', )
                    ],
        )
        """

    def testChatHistoryItem(self):
        """Test ChatHistoryItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
