# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from openai_connector.models.image_settings import ImageSettings

class PromptBundleForGenerateImage(BaseModel):
    """
    PromptBundleForGenerateImage
    """
    system_prompt: StrictStr = Field(...)
    user_prompt: StrictStr = Field(...)
    image_settings: ImageSettings = Field(...)
    skip_moderation: Optional[StrictBool] = False
    __properties = ["system_prompt", "user_prompt", "image_settings", "skip_moderation"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PromptBundleForGenerateImage:
        """Create an instance of PromptBundleForGenerateImage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of image_settings
        if self.image_settings:
            _dict['image_settings'] = self.image_settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PromptBundleForGenerateImage:
        """Create an instance of PromptBundleForGenerateImage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PromptBundleForGenerateImage.parse_obj(obj)

        _obj = PromptBundleForGenerateImage.parse_obj({
            "system_prompt": obj.get("system_prompt"),
            "user_prompt": obj.get("user_prompt"),
            "image_settings": ImageSettings.from_dict(obj.get("image_settings")) if obj.get("image_settings") is not None else None,
            "skip_moderation": obj.get("skip_moderation") if obj.get("skip_moderation") is not None else False
        })
        return _obj


