# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.prompt_bundle_for_generate_image import PromptBundleForGenerateImage  # noqa: E501

class TestPromptBundleForGenerateImage(unittest.TestCase):
    """PromptBundleForGenerateImage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PromptBundleForGenerateImage:
        """Test PromptBundleForGenerateImage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PromptBundleForGenerateImage`
        """
        model = PromptBundleForGenerateImage()  # noqa: E501
        if include_optional:
            return PromptBundleForGenerateImage(
                system_prompt = '',
                user_prompt = '',
                image_settings = openai_connector.models.image_settings.ImageSettings(
                    model = 'dall-e-2', 
                    count = 56, 
                    size = 'auto', 
                    quality = 'low', 
                    output_format = 'png', ),
                skip_moderation = True
            )
        else:
            return PromptBundleForGenerateImage(
                system_prompt = '',
                user_prompt = '',
                image_settings = openai_connector.models.image_settings.ImageSettings(
                    model = 'dall-e-2', 
                    count = 56, 
                    size = 'auto', 
                    quality = 'low', 
                    output_format = 'png', ),
        )
        """

    def testPromptBundleForGenerateImage(self):
        """Test PromptBundleForGenerateImage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
