# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.prompt_bundle import PromptBundle  # noqa: E501

class TestPromptBundle(unittest.TestCase):
    """PromptBundle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PromptBundle:
        """Test PromptBundle
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PromptBundle`
        """
        model = PromptBundle()  # noqa: E501
        if include_optional:
            return PromptBundle(
                model = '',
                system_prompt = '',
                history = [
                    openai_connector.models.chat_history_item.ChatHistoryItem(
                        role = 'user', 
                        content = [
                            openai_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                                type = 'text', 
                                text = '', )
                            ], )
                    ],
                user_prompt = '',
                file = openai_connector.models.file_payload.FilePayload(
                    payload = '', 
                    prompt = '', ),
                response_schema = openai_connector.models.response_schema_payload.ResponseSchemaPayload(
                    properties = {
                        'key' : { }
                        }, 
                    name = '', ),
                skip_moderation = True
            )
        else:
            return PromptBundle(
                system_prompt = '',
                user_prompt = '',
        )
        """

    def testPromptBundle(self):
        """Test PromptBundle"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
